@@ -3,10 +3,10 @@
 High level python EVM interface
 
 Usage:
-  lk ( b | balance  ) <address>
-  lk ( s | save     ) <contract>                                       [--as=<name>]           <address>
-  lk ( d | deploy   ) <contract> [ -v | -q ] [ -j | -J ] [--v=<value>] [--as=<name>] ( [--] [<args>...] | -a <address> )
-  lk ( x | execute  ) <contract> [ -v | -q ] [ -j | -J ] [--v=<value>] ( <function>    [--] [<args>...] | -a )
+  lk ( b | balance  )                                                                   <address>
+  lk ( s | save     ) <contract>                  [--as=<name>]                         <address>
+  lk ( d | deploy   ) <contract> [-vqjJs <value>] [--as=<name>] ( [--] [<args>...] | -a <address> )
+  lk ( x | execute  ) <contract> [-vqjJs <value>] ( <function>    [--] [<args>...] | -a )
   lk -h | --help
   lk --version
 
@@ -15,16 +15,16 @@ Options:
   -v            verbose mode
   -J            JSON mode on
   -j            JSON mode off
-  -a            show address
+  -a            address
   <contract>    name of the contract
   <function>    name of the function
   --as=<name>   name to save contract under
-  --v=<value>   value to send
+  -s --send=<value>   value to send
   -h --help     show this screen.
   --version     show version.
 '''
 import os, sys, json, time, functools as F
-w3, __version__ = None, '3.6.1'
+w3, __version__ = None, '3.6.6'
 def get_balance(address=None):
     return w3.eth.get_balance(address or w3.eth.default_account)
 def w3_connect(default_account, onion=None):
@@ -204,7 +204,7 @@ def main():
     nname   = A['--as']
     name    = A['<contract>']
     func    = A['<function>']
-    value   = A['--v'] or 0
+    value   = A['--send'] or 0
     unit    = 'wei'
     if not A['-j'] and not A['-J']: j = True
     if value and type(value)==type(""):
