@@ -19,6 +19,6 @@ export PRIVATE=0x5e11b147beb73fb3cfc2a2a193484136d2767bc2d4478e41c7e0d1e10d0d4d5
 
 export WETH9=0xd0A1E359811322d97991E03f863a0C30C2cF029C
 
-echo Using Network $NETWORK...
+echo ">> Using Network $NETWORK..."
 
 $*
